==> ews-javascript-api-0.1.3.tgz: package/js/PropertyDefinitions/IndexedPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlAttributeNames_1 = require("../Core/XmlAttributeNames");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var ServiceObjectPropertyDefinition_1 = require("./ServiceObjectPropertyDefinition");
var IndexedPropertyDefinition = (function (_super) {
    __extends(IndexedPropertyDefinition, _super);
    function IndexedPropertyDefinition(uri, index) {
        _super.call(this, uri);
        this.index = index;
    }
    Object.defineProperty(IndexedPropertyDefinition.prototype, "Index", {
        get: function () { return this.index; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IndexedPropertyDefinition.prototype, "Type", {
        get: function () { return 'string'; /*return typeof string;*/ } //System.Type;
        ,
        enumerable: true,
        configurable: true
    });
    //AddJsonProperties(jsonPropertyDefinition: JsonObject, service: ExchangeService): any { throw new Error("IndexedPropertyDefinition.ts - AddJsonProperties : Not implemented."); }
    IndexedPropertyDefinition.prototype.Equals = function (obj) {
        var propertyDefinition = obj;
        return IndexedPropertyDefinition.IsEqualTo(propertyDefinition, this);
    };
    IndexedPropertyDefinition.prototype.GetHashCode = function () { throw new Error("IndexedPropertyDefinition.ts - GetHashCode : Not implemented."); };
    //GetJsonType(): string { throw new Error("IndexedPropertyDefinition.ts - GetJsonType : Not implemented."); }
    IndexedPropertyDefinition.prototype.GetPrintableName = function () { return ExtensionMethods_1.StringHelper.Format("{0}:{1}", this.Uri, this.Index); };
    IndexedPropertyDefinition.prototype.GetXmlElementName = function () { return XmlElementNames_1.XmlElementNames.IndexedFieldURI; };
    IndexedPropertyDefinition.IsEqualTo = function (idxPropDef1, idxPropDef2) {
        return idxPropDef1 === idxPropDef2 ||
            (idxPropDef1.Uri == idxPropDef2.Uri &&
                idxPropDef1.Index == idxPropDef2.Index);
    };
    IndexedPropertyDefinition.prototype.WriteAttributesToXml = function (writer) {
        _super.prototype.WriteAttributesToXml.call(this, writer);
        writer.WriteAttributeValue("", XmlAttributeNames_1.XmlAttributeNames.FieldIndex, this.Index);
    };
    return IndexedPropertyDefinition;
})(ServiceObjectPropertyDefinition_1.ServiceObjectPropertyDefinition);
exports.IndexedPropertyDefinition = IndexedPropertyDefinition;

==> ews-javascript-api-0.1.11.tgz: package/js/PropertyDefinitions/IndexedPropertyDefinition.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var XmlAttributeNames_1 = require("../Core/XmlAttributeNames");
var XmlElementNames_1 = require("../Core/XmlElementNames");
var ExtensionMethods_1 = require("../ExtensionMethods");
var ServiceObjectPropertyDefinition_1 = require("./ServiceObjectPropertyDefinition");
var IndexedPropertyDefinition = (function (_super) {
    __extends(IndexedPropertyDefinition, _super);
    function IndexedPropertyDefinition(uri, index) {
        _super.call(this, uri);
        this.index = index;
    }
    Object.defineProperty(IndexedPropertyDefinition.prototype, "Index", {
        get: function () { return this.index; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IndexedPropertyDefinition.prototype, "Type", {
        get: function () { return 'string'; /*return typeof string;*/ } //System.Type;
        ,
        enumerable: true,
        configurable: true
    });
    //AddJsonProperties(jsonPropertyDefinition: JsonObject, service: ExchangeService): any { throw new Error("IndexedPropertyDefinition.ts - AddJsonProperties : Not implemented."); }
    IndexedPropertyDefinition.prototype.Equals = function (obj) {
        var propertyDefinition = obj;
        return IndexedPropertyDefinition.IsEqualTo(propertyDefinition, this);
    };
    IndexedPropertyDefinition.prototype.GetHashCode = function () { throw new Error("IndexedPropertyDefinition.ts - GetHashCode : Not implemented."); };
    //GetJsonType(): string { throw new Error("IndexedPropertyDefinition.ts - GetJsonType : Not implemented."); }
    IndexedPropertyDefinition.prototype.GetPrintableName = function () { return ExtensionMethods_1.StringHelper.Format("{0}:{1}", this.Uri, this.Index); };
    IndexedPropertyDefinition.prototype.GetXmlElementName = function () { return XmlElementNames_1.XmlElementNames.IndexedFieldURI; };
    IndexedPropertyDefinition.IsEqualTo = function (idxPropDef1, idxPropDef2) {
        return idxPropDef1 === idxPropDef2 ||
            (idxPropDef1.Uri == idxPropDef2.Uri &&
                idxPropDef1.Index == idxPropDef2.Index);
    };
    IndexedPropertyDefinition.prototype.WriteAttributesToXml = function (writer) {
        _super.prototype.WriteAttributesToXml.call(this, writer);
        writer.WriteAttributeValue(XmlAttributeNames_1.XmlAttributeNames.FieldIndex, this.Index);
    };
    return IndexedPropertyDefinition;
})(ServiceObjectPropertyDefinition_1.ServiceObjectPropertyDefinition);
exports.IndexedPropertyDefinition = IndexedPropertyDefinition;
